@@ -3,7 +3,7 @@ package Template::Benchmark::Engines::TemplateSandbox;
 use warnings;
 use strict;
 
-use parent qw/Template::Benchmark::Engine/;
+use base qw/Template::Benchmark::Engine/;
 
 use Template::Sandbox;
 use Template::Sandbox::StringFunctions qw/substr/;
@@ -12,7 +12,7 @@ use Cache::CacheFactory;
 use Cache::FastMmap;
 use CHI;
 
-our $VERSION = '0.99_01';
+our $VERSION = '0.99_02';
 
 our %feature_syntaxes = (
     literal_text              => <<END_OF_TEMPLATE,
