@@ -3,12 +3,12 @@ package Template::Benchmark::Engines::TextMicroTemplate;
 use warnings;
 use strict;
 
-use parent qw/Template::Benchmark::Engine/;
+use base qw/Template::Benchmark::Engine/;
 
 use Text::MicroTemplate;
 use Text::MicroTemplate::File;
 
-our $VERSION = '0.99_01';
+our $VERSION = '0.99_02';
 
 our %feature_syntaxes = (
     literal_text              => <<END_OF_TEMPLATE,
